@@ -391,52 +391,98 @@ void OdtHtmlConverter::createHtmlHead(KoXmlWriter *writer, QHash<QString, QStrin
 
 void OdtHtmlConverter::handleTagTable(KoXmlElement &nodeElement, KoXmlWriter *htmlWriter)
 {
-    QString styleName = nodeElement.attribute("style-name");
+    QString styleName = cssClassName(nodeElement.attribute("style-name"));
     StyleInfo *styleInfo = m_styles.value(styleName);
     htmlWriter->startElement("table", m_doIndent);
     if (styleInfo) {
         styleInfo->inUse = true;
         htmlWriter->addAttribute("class", styleName);
     }
-    htmlWriter->addAttribute("border", "1");
+    htmlWriter->addAttribute("style", "border-collapse: collapse");
 
-    //===== table-row ======
     KoXmlElement tableElement;
     forEachElement (tableElement, nodeElement) {
-        if (tableElement.localName() != "table-column" && tableElement.namespaceURI() == KoXmlNS::table) {
-            htmlWriter->startElement("tr", m_doIndent);
 
-            // ===== table-cell ======
-            KoXmlElement cellElement;
-            forEachElement (cellElement, tableElement) {
-                QString styleName = cellElement.attribute("style-name");
-                StyleInfo *styleInfo = m_styles.value(styleName);
-                htmlWriter->startElement("td", m_doIndent);
-                if (styleInfo) {
-                    styleInfo->inUse = true;
-                    htmlWriter->addAttribute("class", styleName);
-                }
+        //Table headers
+        if (tableElement.localName() == "table-header-rows" && tableElement.namespaceURI() == KoXmlNS::table) {
+            htmlWriter->startElement("thead", m_doIndent);
 
-                // ==== cell text ====
-                // FIXME: This is wrong. A cell element can contain
-                //        the same tags as the full contents, not just
-                //        what is inside a paragraph. (Beside, this
-                //        function has a strange name.)
-                handleInsideElementsTag(cellElement, htmlWriter);
-                // ===================
-                htmlWriter->endElement(); // td
-            } // end for write tag cell
+            KoXmlElement headerRow;
+            forEachElement (headerRow, tableElement) {
+                handleTagTableRow(headerRow, htmlWriter, TableHeaderType);
+            }
 
-            htmlWriter->endElement(); // tr
-        } // end while write tag row
+            htmlWriter->endElement(); //thead
+        }
+
+        //Table body
+        if (tableElement.localName() == "table-rows" && tableElement.namespaceURI() == KoXmlNS::table) {
+            htmlWriter->startElement("tbody", m_doIndent);
+
+            KoXmlElement rowElement;
+            forEachElement (rowElement, tableElement) {
+                handleTagTableRow(rowElement, htmlWriter);
+            }
+
+            htmlWriter->endElement(); //tbody
+        }
+
+        //Tables without headers have no table-rows element and instead embed rows directly in the table,
+        //so handle that properly.
+        if (tableElement.localName() == "table-row" && tableElement.namespaceURI() == KoXmlNS::table) {
+            handleTagTableRow(tableElement, htmlWriter);
+        }
     }
 
-    htmlWriter->endElement();
+    htmlWriter->endElement(); //table
+}
+
+void OdtHtmlConverter::handleTagTableRow(KoXmlElement& nodeElement, KoXmlWriter* htmlWriter, OdtHtmlConverter::TableCellType type)
+{
+    htmlWriter->startElement("tr", m_doIndent);
+
+    KoXmlElement cellElement;
+    forEachElement (cellElement, nodeElement) {
+
+        if (cellElement.localName() == "covered-table-cell") {
+            continue;
+        }
+
+        htmlWriter->startElement(type == TableHeaderType ? "th" : "td", m_doIndent);
+
+        if (cellElement.hasAttributeNS(KoXmlNS::table, "style-name")) {
+            QString styleName = cssClassName(cellElement.attribute("style-name"));
+            StyleInfo *styleInfo = m_styles.value(styleName);
+            if(styleInfo) {
+                styleInfo->inUse = true;
+                htmlWriter->addAttribute("class", styleName);
+            }
+        }
+
+        if (cellElement.hasAttributeNS(KoXmlNS::table, "number-rows-spanned")) {
+            htmlWriter->addAttribute("rowspan", cellElement.attribute("number-rows-spanned"));
+        }
+
+        if (cellElement.hasAttributeNS(KoXmlNS::table, "number-columns-spanned")) {
+            htmlWriter->addAttribute("colspan", cellElement.attribute("number-columns-spanned"));
+        }
+
+        // ==== cell text ====
+        // FIXME: This is wrong. A cell element can contain
+        //        the same tags as the full contents, not just
+        //        what is inside a paragraph. (Beside, this
+        //        function has a strange name.)
+        handleInsideElementsTag(cellElement, htmlWriter);
+
+        htmlWriter->endElement(); //td
+    }
+
+    htmlWriter->endElement(); //tr
 }
 
 void OdtHtmlConverter::handleTagFrame(KoXmlElement &nodeElement, KoXmlWriter *htmlWriter)
 {
-    QString styleName = nodeElement.attribute("style-name");
+    QString styleName = cssClassName(nodeElement.attribute("style-name"));
     StyleInfo *styleInfo = m_styles.value(styleName);
     htmlWriter->startElement("img", m_doIndent);
     if (styleInfo) {
@@ -493,7 +539,7 @@ void OdtHtmlConverter::handleTagFrame(KoXmlElement &nodeElement, KoXmlWriter *ht
 
 void OdtHtmlConverter::handleTagP(KoXmlElement &nodeElement, KoXmlWriter *htmlWriter)
 {
-    QString styleName = nodeElement.attribute("style-name");
+    QString styleName = cssClassName(nodeElement.attribute("style-name"));
     StyleInfo *styleInfo = m_styles.value(styleName);
     htmlWriter->startElement("p", m_doIndent);
     if (styleInfo) {
@@ -512,7 +558,7 @@ void OdtHtmlConverter::handleCharacterData(KoXmlNode &node, KoXmlWriter *htmlWri
 
 void OdtHtmlConverter::handleTagSpan(KoXmlElement &nodeElement, KoXmlWriter *htmlWriter)
 {
-    QString styleName = nodeElement.attribute("style-name");
+    QString styleName = cssClassName(nodeElement.attribute("style-name"));
     StyleInfo *styleInfo = m_styles.value(styleName);
     htmlWriter->startElement("span", m_doIndent);
     if (styleInfo) {
@@ -530,7 +576,7 @@ void OdtHtmlConverter::handleTagPageBreak(KoXmlElement &nodeElement, KoXmlWriter
 
 void OdtHtmlConverter::handleTagH(KoXmlElement &nodeElement, KoXmlWriter *htmlWriter)
 {
-    QString styleName = nodeElement.attribute("style-name");
+    QString styleName = cssClassName(nodeElement.attribute("style-name"));
     StyleInfo *styleInfo = m_styles.value(styleName);
     htmlWriter->startElement("h1", m_doIndent);
     if (styleInfo) {
@@ -543,7 +589,7 @@ void OdtHtmlConverter::handleTagH(KoXmlElement &nodeElement, KoXmlWriter *htmlWr
 
 void OdtHtmlConverter::handleTagList(KoXmlElement &nodeElement, KoXmlWriter *htmlWriter)
 {
-    QString styleName = nodeElement.attribute("style-name");
+    QString styleName = cssClassName(nodeElement.attribute("style-name"));
     StyleInfo *styleInfo = m_styles.value(styleName);
     htmlWriter->startElement("ul", m_doIndent);
     if (styleInfo) {
@@ -691,11 +737,9 @@ void OdtHtmlConverter::handleInsideElementsTag(KoXmlElement &nodeElement, KoXmlW
     KoXmlNode node = nodeElement.firstChild();
     KoXmlElement element = node.toElement();
 
-    // We should end tag "a" after text for bookmark-start we can
-    // handle it with tag bookmark-end but for bookmark there is no
-    // bookmark-end so i use this flag to close the tag "a" that i
-    // have opened it in handleTagBookMark()
-    bool bookMarkFlag = false;
+    // handle it with tag bookmark-end but for bookmark we may have
+    // bookmark-end or we may not have it so we control it with "insideBookmarkTag".
+    bool insideBookmarkTag = false;
 
     // We have characterData or image or span or s  or soft-page break in a tag p
     // FIXME: we should add if there are more tags.
@@ -703,9 +747,10 @@ void OdtHtmlConverter::handleInsideElementsTag(KoXmlElement &nodeElement, KoXmlW
 
         if (node.isText()) {
             handleCharacterData(node, htmlWriter);
-            if (bookMarkFlag) {
+            if (insideBookmarkTag) {
+                // End tag <a> started in bookmark or bookmark-start.
                 htmlWriter->endElement(); // end tag "a"
-                bookMarkFlag = false;
+                insideBookmarkTag = false;
             }
         }
         else if (element.localName() == "p" && element.namespaceURI() == KoXmlNS::text) {
@@ -743,13 +788,15 @@ void OdtHtmlConverter::handleInsideElementsTag(KoXmlElement &nodeElement, KoXmlW
         }
         else if (element.localName() == "bookmark" && element.namespaceURI() == KoXmlNS::text) {
             handleTagBookMark(element, htmlWriter);
-            bookMarkFlag = true;
+            insideBookmarkTag = true;
         }
         else if (element.localName() == "bookmark-start" && element.namespaceURI() == KoXmlNS::text) {
             handleTagBookMarkStart(element, htmlWriter);
+            insideBookmarkTag = true;
         }
         else if (element.localName() == "bookmark-end" && element.namespaceURI() == KoXmlNS::text) {
-            handleTagBookMarkEnd(htmlWriter);
+            // End tag <a> started in bookmark or bookmark-start.
+//            handleTagBookMarkEnd(htmlWriter);
         }
         else if (element.localName() == "note" && element.namespaceURI() == KoXmlNS::text) {
             handleTagNote(element, htmlWriter);
@@ -936,11 +983,13 @@ void OdtHtmlConverter::collectStyleSet(KoXmlNode &stylesNode, QHash<QString, Sty
 
         StyleInfo *styleInfo = new StyleInfo;
 
-        // Get the style name. Default styles don't have a name so
-        // give them a constructed name by combining "default" and the
-        // style family in a way that should not collide with any real
-        // style name.
-        QString styleName = styleElement.attribute("name");
+        // Get the style name. "." is an illegal character in css style
+        // names and needs to be replaced.
+        QString styleName = cssClassName(styleElement.attribute("name"));
+
+        // Default styles don't have a name so give them a constructed
+        // name by combining "default" and the style family in a way
+        // that should not collide with any real style name.
         if (tagName == "default-style") {
             // This name should not collide with any real name.
             styleName = QString("default%") + styleElement.attribute("family");
@@ -951,7 +1000,7 @@ void OdtHtmlConverter::collectStyleSet(KoXmlNode &stylesNode, QHash<QString, Sty
 
         // Every style should have a parent. If the style has no
         // parent, then use the appropriate default style.
-        QString parentName = styleElement.attribute("parent-style-name");
+        QString parentName = cssClassName(styleElement.attribute("parent-style-name"));
         if (!styleInfo->isDefaultStyle && parentName.isEmpty()) {
             parentName = QString("default%") + styleInfo->family;
         }
@@ -1254,3 +1303,10 @@ void OdtHtmlConverter::flattenStyle(const QString &styleName, QHash<QString, Sty
 
     doneStyles.insert(styleName);
 }
+
+QString OdtHtmlConverter::cssClassName(const QString& odfStyleName)
+{
+    QString retval = odfStyleName;
+    QRegExp exp("[^a-zA-Z0-9_]"); //CSS class names are only allowed to use alphanumeric and underscore.
+    return retval.replace(exp, "_sc_"); //Not pretty, but it should serve to create unique class names.
+}
