@@ -18,8 +18,8 @@
 #ifndef RTFREADER_KEYWORDSPCDATADESTINATION_H
 #define RTFREADER_KEYWORDSPCDATADESTINATION_H
 
-#include <QtCore/QString>
-#include <QtGui/QColor>
+#include <QString>
+#include <QColor>
 
 #include "PcdataDestination.h"
 #include "rtfreader_export.h"
@@ -38,4 +38,4 @@ namespace RtfReader
       };
 }
 
-#endif
\ No newline at end of file
+#endif
