@@ -839,10 +839,11 @@ void KexiFormView::slotModified()
     KexiView::setDirty(form()->isModified());
 }
 
-KexiDB::SchemaData*
-KexiFormView::storeNewData(const KexiDB::SchemaData& sdata, bool &cancel)
+KexiDB::SchemaData* KexiFormView::storeNewData(const KexiDB::SchemaData& sdata,
+                                               KexiView::StoreNewDataOptions options,
+                                               bool &cancel)
 {
-    KexiDB::SchemaData *s = KexiView::storeNewData(sdata, cancel);
+    KexiDB::SchemaData *s = KexiView::storeNewData(sdata, options, cancel);
     kDebug() << "new id:" << s->id();
 
     if (!s || cancel) {
