@@ -25,6 +25,7 @@
 #include <QDebug>
 #include <QProcess>
 #include <QProcessEnvironment>
+#include <QDesktopServices>
 #include <QDir>
 
 #include <kglobal.h>
@@ -38,6 +39,10 @@
 #include "data/splash/splash_screen.xpm"
 #include "ui/kis_aboutdata.h"
 
+#ifdef Q_OS_WIN
+#include "stdlib.h"
+#endif
+
 extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
 {
 #ifdef Q_WS_X11
@@ -63,6 +68,42 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
     QSplashScreen *splash = new KSplashScreen(pm);
     app.setSplashScreen(splash);
 
+#ifdef Q_OS_WIN
+    QDir appdir(app.applicationDirPath());
+    appdir.cdUp();
+
+    QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+    // If there's no kdehome, set it
+
+    if (!env.contains("KDEHOME") ) {
+        _putenv_s("KDEHOME", QDesktopServices::storageLocation(QDesktopServices::DataLocation).toLocal8Bit());
+    }
+    if (!env.contains("KDESYCOCA")) {
+        _putenv_s("KDESYCOCA", QString(appdir.absolutePath() + "/sycoca").toLocal8Bit());
+    }
+    if (!env.contains("XDG_DATA_DIRS")) {
+        _putenv_s("XDG_DATA_DIRS", QString(appdir.absolutePath() + "/share").toLocal8Bit());
+    }
+    if (!env.contains("KDEDIR")) {
+        _putenv_s("KDEDIR", appdir.absolutePath().toLocal8Bit());
+    }
+    if (!env.contains("KDEDIRS")) {
+        _putenv_s("KDEDIRS", appdir.absolutePath().toLocal8Bit());
+    }
+    _putenv_s("PATH", QString(appdir.absolutePath() + "/bin" + ";"
+              + appdir.absolutePath() + "/lib" + ";"
+              + appdir.absolutePath() + "/lib"  +  "/kde4" + ";"
+              + appdir.absolutePath()).toLocal8Bit());
+
+    app.addLibraryPath(appdir.absolutePath());
+    app.addLibraryPath(appdir.absolutePath() + "/bin");
+    app.addLibraryPath(appdir.absolutePath() + "/lib");
+    app.addLibraryPath(appdir.absolutePath() + "/lib/kde4");
+#endif
+
+
+
+
     if (!app.start()) {
         return 1;
     }
@@ -75,14 +116,6 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
 
     delete aboutData;
 
-#ifdef Q_OS_WIN
-    QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
-    QDir appdir(app.applicationDirPath());
-    //const QString path = KStandardDirs::findExe( QLatin1String("kdeinit4" ) );
-    Q_ASSERT(QFile(appdir.canonicalPath() + "kdeinit4.exe").exists());
-    QProcess::startDetached(appdir.canonicalPath() + "kdeinit4 --terminate");
-#endif
-
     return state;
 }
 
