@@ -54,8 +54,6 @@ private:
 
 private:
     bool                      m_firstRun;
-    double                    m_angle;
-    quint32                   m_brushIndex;
     KisPaintDeviceSP          m_tempDev;
     KisImageWSP               m_image;
     KisPainter*               m_tempPainter;
