@@ -37,11 +37,9 @@ public:
     explicit KisToolInvocationAction(KisInputManager *manager);
     virtual ~KisToolInvocationAction();
 
-    virtual void begin(int shortcut);
-    virtual void end();
-    virtual void inputEvent(QEvent* event);
-
-    virtual bool handleTablet() const;
+    void begin(int shortcut, QEvent *event);
+    void end(QEvent *event);
+    void inputEvent(QEvent* event);
 
 private:
     class Private;
