@@ -38,12 +38,17 @@
 #include <QMutex>
 #include <QSet>
 #include <QProgressBar>
+#include <QProcess>
+#include <QDir>
+#include <QFile>
+#include <QFileInfo>
 
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <klocale.h>
 #include <KMimeType>
+#include <KStandardDirs>
 
 #include <memory>
 
@@ -186,8 +191,8 @@ int KexiDB::idForObjectName(Connection &conn, const QString& objName, int objTyp
 {
     RecordData data;
     if (true != conn.querySingleRecord(
-                QString::fromLatin1("select o_id from kexi__objects where lower(o_name)='%1' and o_type=%2")
-                .arg(objName.toLower()).arg(objType), data))
+                QString::fromLatin1("select o_id from kexi__objects where o_name='%1' and o_type=%2")
+                .arg(objName).arg(objType), data))
         return 0;
     bool ok;
     int id = data[0].toInt(&ok);
@@ -313,7 +318,7 @@ QueryColumnInfo* TableOrQuerySchema::columnInfo(const QString& name)
     return 0;
 }
 
-QString TableOrQuerySchema::debugString()
+QString TableOrQuerySchema::debugString() const
 {
     if (m_table)
         return m_table->debugString();
@@ -322,7 +327,7 @@ QString TableOrQuerySchema::debugString()
     return QString();
 }
 
-void TableOrQuerySchema::debug()
+void TableOrQuerySchema::debug() const
 {
     if (m_table)
         return m_table->debug();
@@ -677,7 +682,7 @@ struct KexiDB_BuiltinFieldProperties {
         ADD("maxLengthIsDefault");
         ADD("precision");
         ADD("defaultValue");
-        ADD("width");
+        ADD("defaultWidth");
         ADD("visibleDecimalPlaces");
 //! @todo always update this when new builtins appear!
 #undef ADD
@@ -694,9 +699,93 @@ bool KexiDB::isBuiltinTableFieldProperty(const QByteArray& propertyName)
     return KexiDB_builtinFieldProperties->set.contains(propertyName);
 }
 
-bool KexiDB::setFieldProperties(Field& field, const QHash<QByteArray, QVariant>& values)
+namespace KexiDB {
+void getProperties(const LookupFieldSchema *lookup, QMap<QByteArray, QVariant> *values)
 {
-    QHash<QByteArray, QVariant>::ConstIterator it;
+    Q_ASSERT(values);
+    LookupFieldSchema::RowSource rowSource;
+    if (lookup) {
+        rowSource = lookup->rowSource();
+    }
+    values->insert("rowSource", lookup ? rowSource.name() : QVariant());
+    values->insert("rowSourceType", lookup ? rowSource.typeName() : QVariant());
+    values->insert("rowSourceValues",
+        (lookup && !rowSource.values().isEmpty()) ? rowSource.values() : QVariant());
+    values->insert("boundColumn", lookup ? lookup->boundColumn() : QVariant());
+    QList<QVariant> variantList;
+    if (!lookup || lookup->visibleColumns().count() == 1) {
+        values->insert("visibleColumn", lookup ? lookup->visibleColumns().first() : QVariant());
+    }
+    else {
+        QList<uint> visibleColumns = lookup->visibleColumns();
+        foreach(const QVariant& variant, visibleColumns) {
+            variantList.append(variant);
+        }
+        values->insert("visibleColumn", variantList);
+    }
+    QList<int> columnWidths;
+    variantList.clear();
+    if (lookup) {
+        columnWidths = lookup->columnWidths();
+        foreach(const QVariant& variant, columnWidths) {
+            variantList.append(variant);
+        }
+    }
+    values->insert("columnWidths", lookup ? variantList : QVariant());
+    values->insert("showColumnHeaders", lookup ? lookup->columnHeadersVisible() : QVariant());
+    values->insert("listRows", lookup ? lookup->maximumListRows() : QVariant());
+    values->insert("limitToList", lookup ? lookup->limitToList() : QVariant());
+    values->insert("displayWidget", lookup ? uint(lookup->displayWidget()) : QVariant());
+}
+} // namespace KexiDB
+
+void KexiDB::getFieldProperties(const Field &field, QMap<QByteArray, QVariant> *values)
+{
+    Q_ASSERT(values);
+    values->clear();
+    // normal values
+    values->insert("type", field.type());
+    const uint constraints = field.constraints();
+    values->insert("primaryKey", constraints & KexiDB::Field::PrimaryKey);
+    values->insert("indexed", constraints & KexiDB::Field::Indexed);
+    values->insert("autoIncrement", KexiDB::Field::isAutoIncrementAllowed(field.type())
+                                    && (constraints & KexiDB::Field::AutoInc));
+    values->insert("unique", constraints & KexiDB::Field::Unique);
+    values->insert("notNull", constraints & KexiDB::Field::NotNull);
+    values->insert("allowEmpty", !(constraints & KexiDB::Field::NotEmpty));
+    const uint options = field.options();
+    values->insert("unsigned", options & KexiDB::Field::Unsigned);
+    values->insert("name", field.name());
+    values->insert("caption", field.caption());
+    values->insert("description", field.description());
+    values->insert("maxLength", field.maxLength());
+    values->insert("maxLengthIsDefault", field.maxLengthStrategy() & Field::DefaultMaxLength);
+    values->insert("precision", field.precision());
+    values->insert("defaultValue", field.defaultValue());
+#warning TODO    values->insert("defaultWidth", field.defaultWidth());
+    if (KexiDB::supportsVisibleDecimalPlacesProperty(field.type())) {
+        values->insert("visibleDecimalPlaces", field.defaultValue());
+    }
+    // insert lookup-related values
+    LookupFieldSchema *lookup = field.table()->lookupFieldSchema(field);
+    KexiDB::getProperties(lookup, values);
+}
+
+static bool containsLookupFieldSchemaProperties(const QMap<QByteArray, QVariant>& values)
+{
+    for (QMap<QByteArray, QVariant>::ConstIterator it(values.constBegin());
+         it != values.constEnd(); ++it)
+    {
+        if (KexiDB::isLookupFieldSchemaProperty(it.key())) {
+            return true;
+        }
+    }
+    return false;
+}
+
+bool KexiDB::setFieldProperties(Field& field, const QMap<QByteArray, QVariant>& values)
+{
+    QMap<QByteArray, QVariant>::ConstIterator it;
     if ((it = values.find("type")) != values.constEnd()) {
         if (!setIntToFieldType(field, *it))
             return false;
@@ -754,12 +843,37 @@ bool KexiDB::setFieldProperties(Field& field, const QHash<QByteArray, QVariant>&
         return false;
     if ((it = values.find("defaultValue")) != values.constEnd())
         field.setDefaultValue(*it);
+#warning TODO defaultWidth
+#if 0
+    if ((it = values.find("defaultWidth")) != values.constEnd())
+        field.setDefaultWidth((*it).isNull() ? 0/*default*/ : (*it).toUInt(&ok));
+    if (!ok)
+        return false;
+#endif
+
+    // -- extended properties
     if ((it = values.find("visibleDecimalPlaces")) != values.constEnd()
             && KexiDB::supportsVisibleDecimalPlacesProperty(field.type()))
         field.setVisibleDecimalPlaces((*it).isNull() ? -1/*default*/ : (*it).toInt(&ok));
     if (!ok)
         return false;
 
+    if (field.table() && containsLookupFieldSchemaProperties(values)) {
+        LookupFieldSchema *lookup = field.table()->lookupFieldSchema(field);
+        QScopedPointer<LookupFieldSchema> createdLookup;
+        if (!lookup) { // create lookup if needed
+            createdLookup.reset(lookup = new LookupFieldSchema());
+        }
+        if (lookup->setProperties(values)) {
+            if (createdLookup) {
+                if (field.table()->setLookupFieldSchema(field.name(), lookup)) {
+                    createdLookup.take(); // ownership passed
+                    lookup = 0;
+                }
+            }
+        }
+    }
+
     return true;
 #undef SET_BOOLEAN_FLAG
 }
@@ -792,6 +906,26 @@ bool KexiDB::isExtendedTableFieldProperty(const QByteArray& propertyName)
     return KexiDB_extendedProperties->set.contains(QByteArray(propertyName).toLower());
 }
 
+//! @internal for isLookupFieldSchemaProperty()
+struct KexiDB_LookupFieldSchemaProperties {
+    KexiDB_LookupFieldSchemaProperties() {
+        QMap<QByteArray, QVariant> tmp;
+        KexiDB::getProperties(0, &tmp);
+        foreach (const QByteArray &p, tmp.keys()) {
+            set.insert(p.toLower());
+        }
+    }
+    QSet<QByteArray> set;
+};
+
+//! for isLookupFieldSchemaProperty()
+K_GLOBAL_STATIC(KexiDB_LookupFieldSchemaProperties, KexiDB_lookupFieldSchemaProperties)
+
+bool KexiDB::isLookupFieldSchemaProperty(const QByteArray& propertyName)
+{
+    return KexiDB_lookupFieldSchemaProperties->set.contains(QByteArray(propertyName).toLower());
+}
+
 bool KexiDB::setFieldProperty(Field& field, const QByteArray& propertyName, const QVariant& value)
 {
 #define SET_BOOLEAN_FLAG(flag, value) { \
@@ -823,17 +957,19 @@ bool KexiDB::setFieldProperty(Field& field, const QByteArray& propertyName, cons
                 KexiDBWarn << QString(
                     "KexiDB::setFieldProperty() Cannot set \"%1\" property - no table assigned for field!")
                 .arg(QString(propertyName));
-            } else {
+            }
+            else if (KexiDB::isLookupFieldSchemaProperty(propertyName)) {
                 LookupFieldSchema *lookup = field.table()->lookupFieldSchema(field);
-                const bool hasLookup = lookup != 0;
-                if (!hasLookup)
+                const bool createLookup = !lookup;
+                if (createLookup) // create lookup if needed
                     lookup = new LookupFieldSchema();
-                if (LookupFieldSchema::setProperty(*lookup, propertyName, value)) {
-                    if (!hasLookup && lookup)
+                if (lookup->setProperty(propertyName, value)) {
+                    if (createLookup)
                         field.table()->setLookupFieldSchema(field.name(), lookup);
                     return true;
                 }
-                delete lookup;
+                if (createLookup)
+                    delete lookup; // not set, delete
             }
         }
     } else {//non-extended
@@ -889,7 +1025,11 @@ bool KexiDB::setFieldProperty(Field& field, const QByteArray& propertyName, cons
             field.setDefaultValue(value);
             return true;
         }
-
+#warning TODO defaultWidth
+#if 0
+        if ("defaultWidth" == propertyName)
+            GET_INT(setDefaultWidth);
+#endif
         // last chance that never fails: custom field property
         field.setCustomProperty(propertyName, value);
     }
@@ -1464,6 +1604,68 @@ QString KexiDB::string2FileName(const QString &s)
     return fn;
 }
 
+QString KexiDB::temporaryTableName(Connection *conn, const QString &baseName)
+{
+    while (true) {
+        QString name = QLatin1String("tmp__") + baseName;
+        for (int i = 0; i < 10; ++i) {
+            name += QString::number(qrand() % 0x10, 16);
+        }
+        if (!conn->drv_containsTable(name)) {
+            return name;
+        }
+    }
+}
+
+QString KexiDB::sqlite3ProgramPath()
+{
+    QString path = KStandardDirs::findExe("sqlite3");
+    if (path.isEmpty()) {
+        KexiDBWarn << "Could not find program \"sqlite3\"";
+    }
+    return path;
+}
+
+bool KexiDB::importSqliteFile(const QString &inputFileName, const QString &outputFileName)
+{
+    const QString sqlite_app = KexiDB::sqlite3ProgramPath();
+    if (sqlite_app.isEmpty()) {
+        return false;
+    }
+
+    QFileInfo fi(inputFileName);
+    if (!fi.isReadable()) {
+        KexiDBWarn << "No readable input file" << fi.absoluteFilePath();
+        return false;
+    }
+    QFileInfo fo(outputFileName);
+    if (QFile(fo.absoluteFilePath()).exists()) {
+        if (!QFile::remove(fo.absoluteFilePath())) {
+            KexiDBWarn << "Cannot remove output file" << fo.absoluteFilePath();
+            return false;
+        }
+    }
+    kDebug() << inputFileName << fi.absoluteDir().path() << fo.absoluteFilePath();
+
+    QProcess p;
+    p.start(sqlite_app, QStringList() << fo.absoluteFilePath());
+    if (!p.waitForStarted()) {
+        KexiDBWarn << "Failed to start program" << sqlite_app;
+        return false;
+    }
+    QByteArray line(".read " + QFile::encodeName(fi.absoluteFilePath()));
+    if (p.write(line) != line.length() || !p.waitForBytesWritten()) {
+        KexiDBWarn << "Failed to send \".read\" command to program" << sqlite_app;
+        return false;
+    }
+    p.closeWriteChannel();
+    if (!p.waitForFinished()) {
+        KexiDBWarn << "Failed to finish program" << sqlite_app;
+        return false;
+    }
+    return true;
+}
+
 //--------------------------------------------------------------------------------
 
 #ifdef CALLIGRADB_DEBUG_GUI
