@@ -36,7 +36,6 @@
 #include <QSplitter>
 
 #include <kfiledialog.h>
-#include <kiconloader.h>
 #include <klocale.h>
 #include <kdebug.h>
 #include <klineedit.h>
@@ -48,6 +47,8 @@
 #include <knewstuff3/uploaddialog.h>
 #endif
 
+#include <KoIcon.h>
+
 #include "KoResourceServerAdapter.h"
 #include "KoResourceItemView.h"
 #include "KoResourceItemDelegate.h"
@@ -124,21 +125,21 @@ KoResourceItemChooser::KoResourceItemChooser(KoAbstractResourceServerAdapter * r
     QGridLayout* buttonLayout = new QGridLayout;
 
     QPushButton *button = new QPushButton( this );
-    button->setIcon( SmallIcon("document-open") );
+    button->setIcon(koIcon("document-open"));
     button->setToolTip( i18n("Import Resource") );
     button->setEnabled( true );
     d->buttonGroup->addButton( button, Button_Import );
     buttonLayout->addWidget( button, 0, 0 );
 
     button = new QPushButton( this );
-    button->setIcon( SmallIcon("trash-empty") );
+    button->setIcon(koIcon("trash-empty"));
     button->setToolTip( i18n("Delete Resource") );
     button->setEnabled( false );
     d->buttonGroup->addButton( button, Button_Remove );
     buttonLayout->addWidget( button, 0, 1 );
 
     button = new QPushButton( this );
-    button->setIcon( SmallIcon("download") );
+    button->setIcon(koIcon("download"));
     button->setToolTip( i18n("Download Resource") );
     button->setEnabled( true );
     button->hide();
@@ -146,7 +147,7 @@ KoResourceItemChooser::KoResourceItemChooser(KoAbstractResourceServerAdapter * r
     buttonLayout->addWidget( button, 0, 3 );
 
     button = new QPushButton( this );
-    button->setIcon( SmallIcon("go-up") );
+    button->setIcon(koIcon("go-up"));
     button->setToolTip( i18n("Share Resource") );
     button->setEnabled( false );
     button->hide();
