@@ -55,8 +55,9 @@ void FlatProxyModel::sourceHeaderDataChanged(Qt::Orientation orientation, int st
 
 void FlatProxyModel::sourceReset()
 {
+    beginResetModel();
     initiateMaps();
-    reset();
+    endResetModel();
 }
 
 void FlatProxyModel::sourceLayoutAboutToBeChanged()
@@ -70,14 +71,31 @@ void FlatProxyModel::sourceLayoutChanged()
     emit layoutChanged();
 }
 
-void FlatProxyModel::sourceRowsAboutToBeInserted(
-    const QModelIndex &source_parent, int start, int end)
+void FlatProxyModel::sourceRowsAboutToBeInserted(const QModelIndex &source_parent, int start, int end)
 {
-    Q_UNUSED(source_parent);
-    Q_UNUSED(start);
-    Q_UNUSED(end);
-    m_sourceIndexList.clear();
-    m_sourceIndexMap.clear();
+    int rc = sourceModel()->rowCount( source_parent );
+    if ( rc == 0 ) {
+        Q_ASSERT( start == 0 );
+        QModelIndex idx = mapFromSource( source_parent );
+        //kDebug(planDbg())<<"start<rc"<<source_parent<<start<<end<<":"<<idx;
+        if ( idx.isValid() ) {
+            beginInsertRows( QModelIndex(), idx.row() + start, idx.row() + end );
+        } else {
+            beginInsertRows( QModelIndex(), start, end );
+        }
+    } else if ( start < rc ) {
+        QModelIndex source_idx = sourceModel()->index( start, 0, source_parent );
+        QModelIndex idx = mapFromSource( source_idx );
+        //kDebug(planDbg())<<"start<rc"<<source_parent<<start<<end<<":"<<idx;
+        beginInsertRows( QModelIndex(), idx.row(), idx.row() + end - start );
+    } else if ( start == rc ) {
+        QModelIndex source_idx = sourceModel()->index( start - 1, 0, source_parent );
+        QModelIndex idx = mapFromSource( source_idx );
+        //kDebug(planDbg())<<"start==rc"<<source_parent<<start<<end<<":"<<idx;
+        beginInsertRows( QModelIndex(), idx.row() + 1, idx.row() + 1 + end - start );
+    } else {
+        kFatal()<<"Strange data from source model"<<source_parent<<start<<end;
+    }
 }
 
 void FlatProxyModel::sourceRowsInserted(const QModelIndex &source_parent, int start, int end)
@@ -85,13 +103,8 @@ void FlatProxyModel::sourceRowsInserted(const QModelIndex &source_parent, int st
     Q_UNUSED(source_parent);
     Q_UNUSED(start);
     Q_UNUSED(end);
-
-    if ( sourceModel() == 0 ) {
-        kDebug(planDbg())<<"No source model";
-        return;
-    }
     initiateMaps();
-    reset();
+    endInsertRows();
 }
 
 void FlatProxyModel::sourceRowsAboutToBeRemoved( const QModelIndex &source_parent, int start, int end )
@@ -99,6 +112,7 @@ void FlatProxyModel::sourceRowsAboutToBeRemoved( const QModelIndex &source_paren
     Q_UNUSED(source_parent);
     Q_UNUSED(start);
     Q_UNUSED(end);
+    beginResetModel();
 }
 
 void FlatProxyModel::sourceRowsRemoved( const QModelIndex &source_parent, int start, int end )
@@ -108,19 +122,34 @@ void FlatProxyModel::sourceRowsRemoved( const QModelIndex &source_parent, int st
     Q_UNUSED(end);
 
     initiateMaps();
-    reset();
+    endResetModel();
+}
+
+void FlatProxyModel::sourceRowsAboutToBeMoved(const QModelIndex &source_parent, int start, int end, const QModelIndex &destParent, int destStart)
+{
+    beginMoveRows(source_parent, start, end, destParent, destStart );
+}
+
+void FlatProxyModel::sourceRowsMoved(const QModelIndex &source_parent, int start, int end, const QModelIndex &destParent, int destStart)
+{
+    Q_UNUSED(source_parent);
+    Q_UNUSED(start);
+    Q_UNUSED(end);
+    Q_UNUSED(destParent);
+    Q_UNUSED(destStart);
+    kDebug(planDbg());
+    initiateMaps();
+    endMoveRows();
 }
 
 void FlatProxyModel::setSourceModel(QAbstractItemModel *model)
 {
     if ( sourceModel() ) {
-        disconnect(sourceModel(), SIGNAL(destroyed()),
-                 this, SLOT(sourceModelDestroyed()));
         disconnect(sourceModel(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                this, SLOT(_q_sourceDataChanged(QModelIndex,QModelIndex)));
+                this, SLOT(sourceDataChanged(QModelIndex,QModelIndex)));
 
         disconnect(sourceModel(), SIGNAL(headerDataChanged(Qt::Orientation,int,int)),
-                this, SLOT(_q_sourceHeaderDataChanged(Qt::Orientation,int,int)));
+                this, SLOT(sourceHeaderDataChanged(Qt::Orientation,int,int)));
 
         disconnect(sourceModel(), SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)),
                 this, SLOT(sourceRowsAboutToBeInserted(QModelIndex,int,int)));
@@ -138,15 +167,16 @@ void FlatProxyModel::setSourceModel(QAbstractItemModel *model)
                 this, SLOT(sourceLayoutAboutToBeChanged()));
 
         disconnect(sourceModel(), SIGNAL(layoutChanged()),
-                this, SLOT(initiateMaps()));
+                this, SLOT(sourceLayoutChanged()));
 
         disconnect(sourceModel(), SIGNAL(modelReset()), this, SLOT(sourceReset()));
+
+        connect(sourceModel(), SIGNAL(rowsAboutToBeMoved(const QModelIndex&, int, int, const QModelIndex&, int)),
+                this, SLOT(sourceRowsAboutToBeMoved(QModelIndex,int,int,QModelIndex,int)));
+        connect(sourceModel(), SIGNAL(rowsMoved(const QModelIndex&, int, int, const QModelIndex&, int)),
+                this, SLOT(sourceRowsMoved(QModelIndex,int,int,QModelIndex,int)));
     }
-    QAbstractProxyModel::setSourceModel(model ? model : &m_privatemodel);
-    if ( model != &m_privatemodel ) {
-        connect(model, SIGNAL(destroyed()),
-                 this, SLOT(sourceModelDestroyed()));
-    }
+    QAbstractProxyModel::setSourceModel(model);
     connect(sourceModel(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
             this, SLOT(sourceDataChanged(QModelIndex,QModelIndex)));
 
@@ -169,12 +199,18 @@ void FlatProxyModel::setSourceModel(QAbstractItemModel *model)
             this, SLOT(sourceLayoutAboutToBeChanged()));
 
     connect(sourceModel(), SIGNAL(layoutChanged()),
-            this, SLOT(initiateMaps()));
+            this, SLOT(sourceLayoutChanged()));
 
     connect(sourceModel(), SIGNAL(modelReset()), this, SLOT(sourceReset()));
 
+    connect(sourceModel(), SIGNAL(rowsAboutToBeMoved(const QModelIndex&, int, int, const QModelIndex&, int)),
+            this, SLOT(sourceRowsAboutToBeMoved(QModelIndex,int,int,QModelIndex,int)));
+    connect(sourceModel(), SIGNAL(rowsMoved(const QModelIndex&, int, int, const QModelIndex&, int)),
+            this, SLOT(sourceRowsMoved(QModelIndex,int,int,QModelIndex,int)));
+
+    beginResetModel();
     initiateMaps();
-    reset();
+    endResetModel();
 }
 
 QModelIndex FlatProxyModel::index(int row, int column, const QModelIndex &parent) const
@@ -193,8 +229,7 @@ QModelIndex FlatProxyModel::parent(const QModelIndex &child) const
 
 int FlatProxyModel::rowCount(const QModelIndex &parent) const
 {
-    Q_UNUSED(parent);
-    return m_sourceIndexList.count();
+    return parent.isValid() ? 0 : m_sourceIndexList.count();
 }
 
 int FlatProxyModel::columnCount(const QModelIndex &parent) const
@@ -208,8 +243,7 @@ int FlatProxyModel::columnCount(const QModelIndex &parent) const
 
 bool FlatProxyModel::hasChildren(const QModelIndex &parent) const
 {
-    Q_UNUSED(parent);
-    return false;
+    return rowCount( parent ) > 0;
 }
 
 QVariant FlatProxyModel::data(const QModelIndex &index, int role) const
@@ -228,7 +262,7 @@ QVariant FlatProxyModel::data(const QModelIndex &index, int role) const
         //kDebug(planDbg())<<"proxy column"<<col<<sourceModel()->columnCount();
     }
     if ( !source_index.isValid() ) {
-        kDebug(planDbg())<<"index valid but source index not valid";
+        kDebug(planDbg())<<"index valid but source index not valid:"<<index;
         return QVariant();
     }
     QVariant r;
@@ -383,9 +417,12 @@ QModelIndex FlatProxyModel::mapToSource(const QModelIndex &proxyIndex) const
 */
 QModelIndex FlatProxyModel::mapFromSource(const QModelIndex &sourceIndex) const
 {
+    if ( ! sourceIndex.isValid() ) {
+        return QModelIndex();
+    }
     QPersistentModelIndex idx = sourceIndex;
     if ( idx.column() != 0 ) {
-        // we only map indeces with column 0
+        // we only map indices with column 0
         idx = sourceModel()->index( idx.row(), 0, idx.parent() );
     }
     QModelIndex proxy_index = index( m_sourceIndexList.indexOf( idx ), sourceIndex.column() );
@@ -417,6 +454,7 @@ void FlatProxyModel::initiateMaps( const QModelIndex &sourceParent )
     int count = m->rowCount( sourceParent );
     for ( int row = 0; row < count; ++row ) {
         QPersistentModelIndex idx = m->index( row, 0, sourceParent );
+        //kDebug(planDbg())<<"map:"<<sourceParent<<row<<idx;
         if ( idx.isValid() ) { // fail safe
             m_sourceIndexList.append( idx );
             m_sourceIndexMap.insert( idx.parent(), idx );
