@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
- * Copyright (C) 2009, 2010 Dag Andersen <danders@get2net.dk>
+ * Copyright (C) 2009, 2010, 2012 Dag Andersen <danders@get2net.dk>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -24,6 +24,7 @@
 #include "kptresource.h"
 #include "kpttask.h"
 #include "kptrelation.h"
+#include "kptdebug.h"
 
 #include <librcps.h>
 
@@ -33,7 +34,6 @@
 
 #include <KGlobal>
 #include <KLocale>
-#include <KDebug>
 
 #include <iostream>
 
@@ -53,6 +53,7 @@
 #define GROUP_TARGETTIME    1
 #define GROUP_CONSTRAINT    2
 
+
 class ProgressInfo
 {
 public:
@@ -68,7 +69,7 @@ public:
 };
 
 
-KPlatoRCPSScheduler::KPlatoRCPSScheduler( Project *project, ScheduleManager *sm, QObject *parent )
+KPlatoRCPSScheduler::KPlatoRCPSScheduler( Project *project, ScheduleManager *sm, ulong granularity, QObject *parent )
     : SchedulerThread( project, sm, parent ),
     result( -1 ),
     m_schedule( 0 ),
@@ -76,7 +77,7 @@ KPlatoRCPSScheduler::KPlatoRCPSScheduler( Project *project, ScheduleManager *sm,
     m_usePert( false ),
     m_backward( false ),
     m_problem( 0 ),
-    m_timeunit( 60 ),
+    m_timeunit( granularity / 1000 ),
     m_offsetFromTime_t( 0 ),
     m_progressinfo( new ProgressInfo() )
 {
@@ -105,19 +106,19 @@ int KPlatoRCPSScheduler::progress_callback( int generations, struct rcps_fitness
         return -1;
     }
     KPlatoRCPSScheduler *self = static_cast<KPlatoRCPSScheduler*>( arg );
-    //qDebug()<<"KPlatoRCPSScheduler::progress_callback"<<generations<<fitness<<arg;
+    //kDebug(planDbg())<<"KPlatoRCPSScheduler::progress_callback"<<generations<<fitness<<arg;
     return self->progress( generations, fitness );
 }
 
 int KPlatoRCPSScheduler::progress( int generations, struct rcps_fitness fitness )
 {
     if ( m_haltScheduling ) {
-        qDebug()<<"KPlatoRCPSScheduler::progress:"<<"halt";
+        kDebug(planDbg())<<"KPlatoRCPSScheduler::progress:"<<"halt";
         return -1;
     }
     if ( m_stopScheduling ) {
         m_schedule->logWarning( i18n( "Scheduling halted after %1 generations", generations ), 1 );
-        qDebug()<<"KPlatoRCPSScheduler::progress:"<<"stop";
+        kDebug(planDbg())<<"KPlatoRCPSScheduler::progress:"<<"stop";
         return -1;
     }
 //     std::cout << "Progress after: " << generations << " generations\n";
@@ -143,7 +144,7 @@ int KPlatoRCPSScheduler::progress( int generations, struct rcps_fitness fitness
     // stop if fitness does not change in GENERATION_MIN_LIMIT generations
 /*    int result = ( generations >= m_progressinfo->base + GENERATION_MIN_LIMIT ? 1 : 0 );
     if ( result ) {
-        //qDebug()<<"KPlatoRCPSScheduler::progress, stop after"<<generations<<"generations, progress:"<<m_progressinfo->progress;
+        //kDebug(planDbg())<<"KPlatoRCPSScheduler::progress, stop after"<<generations<<"generations, progress:"<<m_progressinfo->progress;
         m_schedule->logDebug( QString( "Acceptable solution found after %1 generations" ).arg( generations ), 1 );
         std::cout << "Acceptable solution found after " << generations << " generations\n";
     }*/
@@ -152,7 +153,7 @@ int KPlatoRCPSScheduler::progress( int generations, struct rcps_fitness fitness
 
 int KPlatoRCPSScheduler::duration_callback( int direction, int time, int nominal_duration, void *arg )
 {
-    //qDebug()<<"kplato_duration:"<<direction<<time<<nominal_duration<<arg;
+    //kDebug(planDbg())<<"kplato_duration:"<<direction<<time<<nominal_duration<<arg;
     if ( arg == 0 ) {
         return nominal_duration;
     }
@@ -189,7 +190,7 @@ int KPlatoRCPSScheduler::duration( int direction, int time, int nominal_duration
                         0, /*no schedule*/
                         m_backward ? ! direction : direction
                     ).seconds() / m_timeunit;
-            //qDebug()<<info->task->name()<< QString( "duration_callback effort: backward=%5, direction=%6 (direction=%7); Time=%1, duration=%2 ( %3, %4 )" ).arg( time ).arg( dur ).arg( fromRcpsTime( time ).toString() ).arg( Duration( (qint64)(dur) * m_timeunit * 1000 ).toDouble( Duration::Unit_h ) ).arg( m_backward ).arg( direction ).arg( m_backward ? !direction : direction );
+            //kDebug(planDbg())<<info->task->name()<< QString( "duration_callback effort: backward=%5, direction=%6 (direction=%7); Time=%1, duration=%2 ( %3, %4 )" ).arg( time ).arg( dur ).arg( fromRcpsTime( time ).toString() ).arg( Duration( (qint64)(dur) * m_timeunit * 1000 ).toDouble( Duration::Unit_h ) ).arg( m_backward ).arg( direction ).arg( m_backward ? !direction : direction );
         }
     } else {
         dur = info->task->length( 
@@ -206,7 +207,7 @@ int KPlatoRCPSScheduler::duration( int direction, int time, int nominal_duration
 
 int KPlatoRCPSScheduler::weight_callback( int time, int duration, struct rcps_fitness *nominal_weight, void* weight_arg, void* fitness_arg )
 {
-    //qDebug()<<"kplato_weight:"<<time<<nominal_weight<<arg;
+    //kDebug(planDbg())<<"kplato_weight:"<<time<<nominal_weight<<arg;
     if ( weight_arg == 0 ) {
         nominal_weight->weight *= time;
         return 0;
@@ -223,7 +224,7 @@ void *KPlatoRCPSScheduler::fitness_callback_init( void *arg )
     Q_ASSERT( info );
     fitness_info *finfo = new fitness_info;
     finfo->self = info->self;
-//     kDebug()<<info->self;
+//     kDebug(planDbg())<<info->self;
     return finfo;
 }
 
@@ -241,7 +242,7 @@ int KPlatoRCPSScheduler::fitness( struct rcps_fitness *fit, KPlatoRCPSScheduler:
     std::cout << "Sequence: ";
     foreach ( Task *t, info->jobs ) { std::cout << (t ? t->name().toLocal8Bit().data() : "End") << ", "; }
     std::cout << "\n";
-    kDebug()<<info->map;*/
+    kDebug(planDbg())<<info->map;*/
     QMultiMap<int, QPair<int, Task*> >::const_iterator it = info->map.constFind( GROUP_CONSTRAINT );
     if ( it != info->map.constEnd() ) {
         // constraint
@@ -382,8 +383,8 @@ int KPlatoRCPSScheduler::weight( int time, int duration, struct rcps_fitness *no
     if ( finfo ) {
         finfo->map.insert( f.group, QPair<int, Task*>( f.weight, info->task ) );
         finfo->jobs << info->task;
-//         kDebug()<<s<<":"<<finfo->map;
-    }// else kDebug()<<s<<":"<<"No finfo!";
+//         kDebug(planDbg())<<s<<":"<<finfo->map;
+    }// else kDebug(planDbg())<<s<<":"<<"No finfo!";
 /*    std::cout << "Weight: " << s.toLocal8Bit().data() << ": group=" << f.group << " weight=" << f.weight << "\n";*/
     return 0;
 }
@@ -414,8 +415,7 @@ void KPlatoRCPSScheduler::run()
         m_manager->setName( "Schedule: " + m_manager->name() ); //Debug
         m_schedule = m_manager->expected();
 
-        bool x = connect(m_manager, SIGNAL(sigLogAdded(Schedule::Log)), this, SLOT(slotAddLog(Schedule::Log)));
-        Q_ASSERT( x );
+        connect(m_manager, SIGNAL(sigLogAdded(Schedule::Log)), this, SLOT(slotAddLog(Schedule::Log)));
 
         m_project->initiateCalculation( *m_schedule );
         m_project->initiateCalculationLists( *m_schedule );
@@ -438,7 +438,7 @@ void KPlatoRCPSScheduler::run()
 
         m_schedule->setPhaseName( 0, i18n( "Init" ) );
         if ( ! m_backward && locale() ) {
-            m_schedule->logDebug( QString( "Schedule project using RCPS Scheduler, starting at %1" ).arg( QDateTime::currentDateTime().toString() ), 0 );
+            m_schedule->logDebug( QString( "Schedule project using RCPS Scheduler, starting at %1, granularity %2 sec" ).arg( QDateTime::currentDateTime().toString() ).arg( m_timeunit ), 0 );
             if ( m_recalculate ) {
                 m_schedule->logInfo( i18n( "Re-calculate project from start time: %1", locale()->formatDateTime( m_starttime ) ), 0 );
             } else {
@@ -446,7 +446,7 @@ void KPlatoRCPSScheduler::run()
             }
         }
         if ( m_backward && locale() ) {
-            m_schedule->logDebug( QString( "Schedule project backward using RCPS Scheduler, starting at %1" ).arg( locale()->formatDateTime( QDateTime::currentDateTime() ) ), 0 );
+            m_schedule->logDebug( QString( "Schedule project backward using RCPS Scheduler, starting at %1, granularity %2 sec" ).arg( locale()->formatDateTime( QDateTime::currentDateTime() ) ).arg( m_timeunit ), 0 );
             m_schedule->logInfo( i18n( "Schedule project from end time: %1", locale()->formatDateTime( m_starttime ) ), 0 );
         }
 
@@ -486,7 +486,7 @@ int KPlatoRCPSScheduler::check()
 
 void KPlatoRCPSScheduler::solve()
 {
-    qDebug()<<"KPlatoRCPSScheduler::solve()";
+    kDebug(planDbg())<<"KPlatoRCPSScheduler::solve()";
     struct rcps_solver *s = rcps_solver_new();
     rcps_solver_set_progress_callback(s, PROGRESS_CALLBACK_FREQUENCY, this, &KPlatoRCPSScheduler::progress_callback);
     rcps_solver_set_duration_callback(s, &KPlatoRCPSScheduler::duration_callback );
@@ -618,7 +618,7 @@ void KPlatoRCPSScheduler::kplatoFromRCPS()
 
 void KPlatoRCPSScheduler::kplatoFromRCPSForward()
 {
-    //qDebug()<<"KPlatoRCPSScheduler::kplatoFromRCPSForward:";
+    //kDebug(planDbg())<<"KPlatoRCPSScheduler::kplatoFromRCPSForward:";
     MainSchedule *cs = static_cast<MainSchedule*>( m_project->currentSchedule() );
     QMap<Node*, QList<ResourceRequest*> > resourcemap;
     int count = rcps_job_count(m_problem);
@@ -753,7 +753,7 @@ void KPlatoRCPSScheduler::taskFromRCPSBackward( struct rcps_job *job, Task *task
 
 void KPlatoRCPSScheduler::kplatoFromRCPSBackward()
 {
-    //qDebug()<<"KPlatoRCPSScheduler::kplatoFromRCPSBackward:";
+    //kDebug(planDbg())<<"KPlatoRCPSScheduler::kplatoFromRCPSBackward:";
     MainSchedule *cs = static_cast<MainSchedule*>( m_project->currentSchedule() );
     QMap<Node*, QList<ResourceRequest*> > resourcemap;
     int count = rcps_job_count( m_problem );
@@ -856,7 +856,7 @@ void KPlatoRCPSScheduler::calculatePertValues( const QMap<Node*, QList<ResourceR
         }
         if ( t->negativeFloat() != 0 ) {
             n->schedule()->setConstraintError( true );
-            n->schedule()->logError( i18nc( "1=type of constraint", "%1: Failed to meet constraint. Negative float=%2", n->constraintToString( true ), t->negativeFloat().toString( Duration::Format_i18nHour ) ) );
+            n->schedule()->logError( i18nc( "1=type of constraint", "%1: Failed to meet constraint. Negative float=%2", n->constraintToString( true ), locale()->formatDuration( t->negativeFloat().milliseconds() ) ) );
         }
 
     }
@@ -987,7 +987,7 @@ struct rcps_resource *KPlatoRCPSScheduler::addResource( KPlato::Resource *r)
 
 void KPlatoRCPSScheduler::addResources()
 {
-    kDebug();
+    kDebug(planDbg());
     QList<Resource*> list = m_project->resourceList();
     for (int i = 0; i < list.count(); ++i) {
         addResource( list.at(i) );
@@ -1015,7 +1015,7 @@ struct rcps_job *KPlatoRCPSScheduler::addTask( KPlato::Task *task )
 
 void KPlatoRCPSScheduler::addTasks()
 {
-    kDebug();
+    kDebug(planDbg());
     // Add a start job
     m_jobstart = rcps_job_new();
     rcps_job_setname( m_jobstart, "RCPS start job" );
@@ -1056,7 +1056,7 @@ void KPlatoRCPSScheduler::addTasks()
     m_weight_info_list[ m_jobend ] = info;
 
     for( int i = 0; i < rcps_job_count( m_problem ); ++i ) {
-        kDebug()<<"Task:"<<rcps_job_getname( rcps_job_get(m_problem, i) );
+        kDebug(planDbg())<<"Task:"<<rcps_job_getname( rcps_job_get(m_problem, i) );
     }
 }
 
@@ -1127,11 +1127,11 @@ void KPlatoRCPSScheduler::addDependenciesBackward( struct rcps_job *job, KPlato:
 {
     if ( task->dependParentNodes().isEmpty() && task->parentProxyRelations().isEmpty() ) {
         rcps_job_successor_add( job, m_jobend, SUCCESSOR_FINISH_START );
-        //qDebug()<<rcps_job_getname( job )<<"->"<<rcps_job_getname( m_jobend );
+        //kDebug(planDbg())<<rcps_job_getname( job )<<"->"<<rcps_job_getname( m_jobend );
     }
     if ( task->dependChildNodes().isEmpty() && task->childProxyRelations().isEmpty() ) {
         rcps_job_successor_add( m_jobstart, job, SUCCESSOR_FINISH_START );
-        //qDebug()<<rcps_job_getname( m_jobstart )<<"->"<<rcps_job_getname( job );
+        //kDebug(planDbg())<<rcps_job_getname( m_jobstart )<<"->"<<rcps_job_getname( job );
     }
     foreach ( Relation *r, task->dependParentNodes() ) {
         Node *n = r->parent();
@@ -1146,15 +1146,15 @@ void KPlatoRCPSScheduler::addDependenciesBackward( struct rcps_job *job, KPlato:
         }
         if ( r->lag() == Duration::zeroDuration ) {
             rcps_job_successor_add( job, m_taskmap.key( static_cast<Task*>( n ) ), type );
-            //qDebug()<<rcps_job_getname( job )<<"->"<<rcps_job_getname( m_taskmap.key( static_cast<Task*>( n ) ) )<<type;
+            //kDebug(planDbg())<<rcps_job_getname( job )<<"->"<<rcps_job_getname( m_taskmap.key( static_cast<Task*>( n ) ) )<<type;
         } else {
             // Add a dummy job to represent the lag
             struct rcps_job *dummy = addJob( r->lag().toString(), r->lag().seconds() / m_timeunit );
             rcps_job_successor_add( job, dummy, type );
-            qDebug()<<rcps_job_getname( job )<<"->"<<"dummy lag"<<type;
+            kDebug(planDbg())<<rcps_job_getname( job )<<"->"<<"dummy lag"<<type;
             int t = type == SUCCESSOR_FINISH_FINISH ? type : SUCCESSOR_FINISH_START;
             rcps_job_successor_add( dummy, m_taskmap.key( static_cast<Task*>( n ) ), t );
-            //qDebug()<<"dummy lag"<<"->"<<rcps_job_getname( m_taskmap.key( static_cast<Task*>( n ) ) )<<t;
+            //kDebug(planDbg())<<"dummy lag"<<"->"<<rcps_job_getname( m_taskmap.key( static_cast<Task*>( n ) ) )<<t;
         }
     }
     foreach ( Relation *r, task->parentProxyRelations() ) {
@@ -1170,22 +1170,22 @@ void KPlatoRCPSScheduler::addDependenciesBackward( struct rcps_job *job, KPlato:
         }
         if ( r->lag() == Duration::zeroDuration ) {
             rcps_job_successor_add( job, m_taskmap.key( static_cast<Task*>( n ) ), type );
-            //qDebug()<<rcps_job_getname( job )<<"->"<<rcps_job_getname( m_taskmap.key( static_cast<Task*>( n ) ) )<<type;
+            //kDebug(planDbg())<<rcps_job_getname( job )<<"->"<<rcps_job_getname( m_taskmap.key( static_cast<Task*>( n ) ) )<<type;
         } else {
             // Add a dummy job to represent the lag
             struct rcps_job *dummy = addJob( r->lag().toString(), r->lag().seconds() / m_timeunit );
             rcps_job_successor_add( job, dummy, type );
-            qDebug()<<rcps_job_getname( job )<<"->"<<"dummy lag"<<type;
+            kDebug(planDbg())<<rcps_job_getname( job )<<"->"<<"dummy lag"<<type;
             int t = type == SUCCESSOR_FINISH_FINISH ? type : SUCCESSOR_FINISH_START;
             rcps_job_successor_add( dummy, m_taskmap.key( static_cast<Task*>( n ) ), t );
-            //qDebug()<<"dummy lag"<<"->"<<rcps_job_getname( m_taskmap.key( static_cast<Task*>( n ) ) )<<t;
+            //kDebug(planDbg())<<"dummy lag"<<"->"<<rcps_job_getname( m_taskmap.key( static_cast<Task*>( n ) ) )<<t;
         }
     }
 }
 
 void KPlatoRCPSScheduler::addDependencies()
 {
-    kDebug();
+    kDebug(planDbg());
     QMap<struct rcps_job*, Task*> ::const_iterator it = m_taskmap.constBegin();
     for ( ; it != m_taskmap.constEnd(); ++it ) {
         if ( m_backward ) {
@@ -1198,7 +1198,7 @@ void KPlatoRCPSScheduler::addDependencies()
 
 void KPlatoRCPSScheduler::addRequests()
 {
-    kDebug();
+    kDebug(planDbg());
     QMap<struct rcps_job*, Task*> ::const_iterator it = m_taskmap.constBegin();
     for ( ; it != m_taskmap.constEnd(); ++it ) {
         addRequest( it.key(), it.value() );
@@ -1207,7 +1207,7 @@ void KPlatoRCPSScheduler::addRequests()
 
 void KPlatoRCPSScheduler::addRequest( rcps_job *job, Task *task )
 {
-    kDebug();
+    kDebug(planDbg());
     struct rcps_mode *mode = rcps_mode_new();
     rcps_mode_add( job, mode );
     // add a weight callback argument
