@@ -49,10 +49,11 @@
 #include <KoConnectionShapeConfigWidget.h>
 #include <KoPathConnectionPointStrategy.h>
 #include <KoToolManager.h>
+#include <KoIcon.h>
+
 #include <KAction>
 #include <KLocale>
 #include <KDebug>
-#include <KIcon>
 #include <KStandardDirs>
 #include <kundo2command.h>
 
@@ -78,44 +79,44 @@ ConnectionTool::ConnectionTool(KoCanvasBase * canvas)
     m_alignPercent = new KAction(QString("%"), this);
     m_alignPercent->setCheckable(true);
     addAction("align-relative", m_alignPercent);
-    m_alignLeft = new KAction(KIcon("align-horizontal-left"), i18n("Align to left edge"), this);
+    m_alignLeft = new KAction(koIcon("align-horizontal-left"), i18n("Align to left edge"), this);
     m_alignLeft->setCheckable(true);
     addAction("align-left", m_alignLeft);
-    m_alignCenterH = new KAction(KIcon("align-horizontal-center"), i18n("Align to horizontal center"), this);
+    m_alignCenterH = new KAction(koIcon("align-horizontal-center"), i18n("Align to horizontal center"), this);
     m_alignCenterH->setCheckable(true);
     addAction("align-centerh", m_alignCenterH);
-    m_alignRight = new KAction(KIcon("align-horizontal-right"), i18n("Align to right edge"), this);
+    m_alignRight = new KAction(koIcon("align-horizontal-right"), i18n("Align to right edge"), this);
     m_alignRight->setCheckable(true);
     addAction("align-right", m_alignRight);
-    m_alignTop = new KAction(KIcon("align-vertical-top"), i18n("Align to top edge"), this);
+    m_alignTop = new KAction(koIcon("align-vertical-top"), i18n("Align to top edge"), this);
     m_alignTop->setCheckable(true);
     addAction("align-top", m_alignTop);
-    m_alignCenterV = new KAction(KIcon("align-vertical-center"), i18n("Align to vertical center"), this);
+    m_alignCenterV = new KAction(koIcon("align-vertical-center"), i18n("Align to vertical center"), this);
     m_alignCenterV->setCheckable(true);
     addAction("align-centerv", m_alignCenterV);
-    m_alignBottom = new KAction(KIcon("align-vertical-bottom"), i18n("Align to bottom edge"), this);
+    m_alignBottom = new KAction(koIcon("align-vertical-bottom"), i18n("Align to bottom edge"), this);
     m_alignBottom->setCheckable(true);
     addAction("align-bottom", m_alignBottom);
 
-    m_escapeAll = new KAction(KIcon("escape-direction-all"), i18n("Escape in all directions"), this);
+    m_escapeAll = new KAction(koIcon("escape-direction-all"), i18n("Escape in all directions"), this);
     m_escapeAll->setCheckable(true);
     addAction("escape-all", m_escapeAll);
-    m_escapeHorizontal = new KAction(KIcon("escape-direction-horizontal"), i18n("Escape in horizontal directions"), this);
+    m_escapeHorizontal = new KAction(koIcon("escape-direction-horizontal"), i18n("Escape in horizontal directions"), this);
     m_escapeHorizontal->setCheckable(true);
     addAction("escape-horizontal", m_escapeHorizontal);
-    m_escapeVertical = new KAction(KIcon("escape-direction-vertical"), i18n("Escape in vertical directions"), this);
+    m_escapeVertical = new KAction(koIcon("escape-direction-vertical"), i18n("Escape in vertical directions"), this);
     m_escapeVertical->setCheckable(true);
     addAction("escape-vertical", m_escapeVertical);
-    m_escapeLeft = new KAction(KIcon("escape-direction-left"), i18n("Escape in left direction"), this);
+    m_escapeLeft = new KAction(koIcon("escape-direction-left"), i18n("Escape in left direction"), this);
     m_escapeLeft->setCheckable(true);
     addAction("escape-left", m_escapeLeft);
-    m_escapeRight = new KAction(KIcon("escape-direction-right"), i18n("Escape in right direction"), this);
+    m_escapeRight = new KAction(koIcon("escape-direction-right"), i18n("Escape in right direction"), this);
     m_escapeRight->setCheckable(true);
     addAction("escape-right", m_escapeRight);
-    m_escapeUp = new KAction(KIcon("escape-direction-up"), i18n("Escape in up direction"), this);
+    m_escapeUp = new KAction(koIcon("escape-direction-up"), i18n("Escape in up direction"), this);
     m_escapeUp->setCheckable(true);
     addAction("escape-up", m_escapeUp);
-    m_escapeDown = new KAction(KIcon("escape-direction-down"), i18n("Escape in down direction"), this);
+    m_escapeDown = new KAction(koIcon("escape-direction-down"), i18n("Escape in down direction"), this);
     m_escapeDown->setCheckable(true);
     addAction("escape-down", m_escapeDown);
 
