@@ -22,7 +22,7 @@
 #define MODEL_H
 
 #include <QAbstractListModel>
-#include <KIcon>
+#include <QSize>
 
 class KoStyleThumbnailer;
 
@@ -32,11 +32,10 @@ class KoCharacterStyle;
 
 class QImage;
 class QSignalMapper;
-class QSize;
 
 /** This class is used to provide widgets (like the @class StylesCombo) the styles available to the document being worked on. The @class StylesModel can be of two types: character styles or paragraph styles type. This allows the widget to ignore the type of style it is handling.
   * Character styles in ODF can be specified in two ways. First, a named character style, specifying character formatting properties. It is meant to be used on a couple of individual characters. Secondely, a paragraph style also specifies character formatting properties, which are to be considered the default for that particular paragraph.
-  * For this reason, the @class Stylesmodel, when of the type @value characterStyle, do not list the paragraph style names. Only the specific named chracter styles are listed. Additionnaly, as the first item, a virtual style "As paragraph" is provided. Selecting this "style" will set the character properties as specified by the paragraph style currently applied to the selection.
+  * For this reason, the @class Stylesmodel, when of the type @value characterStyle, do not list the paragraph style names. Only the specific named chracter styles are listed. Additionally, as the first item, a virtual style "As paragraph" is provided. Selecting this "style" will set the character properties as specified by the paragraph style currently applied to the selection.
   * This class requires that a @class KoStyleManager and a @class KoStyleThumbnailer be set. See below methods.
 */
 
@@ -140,8 +139,6 @@ private:
     KoCharacterStyle *m_defaultCharacterStyle;
     Type m_modelType;
 
-    KIcon m_paragIcon, m_charIcon;
-
     QSignalMapper *m_styleMapper;
 
     bool m_provideStyleNone;
