@@ -34,6 +34,7 @@
 #include <kio/job.h>
 
 #include <KoDocument.h>
+#include <KoPart.h>
 #include <KoFilterManager.h>
 #include <KoPrintJob.h>
 #include <KoView.h>
@@ -45,12 +46,14 @@ bool convertPdf(const KUrl &uIn, const QString &inputFormat, const KUrl &uOut, c
     Q_UNUSED(outputFormat);
 
     QString error;
-    KoDocument *doc = KMimeTypeTrader::self()->createInstanceFromQuery< KoDocument >(
+    KoPart *part = KMimeTypeTrader::self()->createInstanceFromQuery<KoPart>(
                     inputFormat, QLatin1String("CalligraPart"), 0, QString(), QVariantList(), &error);
-    if (!doc) {
+    if (!part) {
         return false;
     }
 
+    KoDocument *doc = part->document();
+
     doc->setCheckAutoSaveFile(false);
     doc->setAutoErrorHandlingEnabled(false);
     if (!doc->openUrl(uIn)) {
@@ -61,7 +64,7 @@ bool convertPdf(const KUrl &uIn, const QString &inputFormat, const KUrl &uOut, c
     }
 
     doc->setReadWrite(false);
-    KoView *view = doc->createView();
+    KoView *view = part->createView();
     KoPrintJob *printJob = view->createPdfPrintJob();
 
     // We should now have a print job - but check to make sure
